% quadrature_intro.m
% A brief introduction to usage of quadratures and projection

%% Create
clear;

corners = [-1, -1; 1, -1; 1, 1; -1, 1];

order = 13;
[xx, ww] = gaussian_quadrature_2d(order, 4);
%% Plot quadrature points
figure;
plot(corners([1:4,1], 1), corners([1:4, 1], 2), 'k-', 'LineWidth', 1.2);
hold on;
plot(xx(:,1), xx(:,2), 'ro', 'LineWidth', 1.2);
xlim(1.1*[-1 1]);
ylim(1.1*[-1 1]);
%% Plot surface of the qudrature
figure;
h = surf(unique(xx(:,1)), unique(xx(:,2)), reshape(ww, sqrt(size(xx,1)), []));
shading interp;
set(h, 'EdgeColor', 'k');
%% Transform into a triangle
N = elem_shape_functions(xx, 4);
new_corners = [0 0; 0 0; 1 0; 0 1];
xx_new = N * new_corners;

%% Plot quadrature points
figure;
plot(new_corners([1:4,1], 1), new_corners([1:4, 1], 2), 'k-', 'LineWidth', 1.2);
hold on;
plot(xx_new(:,1), xx_new(:,2), 'ro', 'LineWidth', 1.2);
xlim([-.1 1.1]);
ylim([-.1 1.1]);

%% Project to arbitrary 3D
tria_corners = [0 0; 1 0; 0 1];
corners_3d = [-.5 -.3 .2; 0.6 0 0.3; 0.1 .2 0.4];
xi = gaussian_quadrature_2d(order, 3);
N = elem_shape_functions(xi, 3);
x = N * corners_3d;

figure;
plot3(corners_3d([1:3,1], 1), corners_3d([1:3, 1], 2), ...
     corners_3d([1:3,1], 3), 'k-', 'LineWidth', 1.2);
hold on;
plot3(x(:,1), x(:,2), x(:,3), 'ro', 'LineWidth', 1.2);

