% quadrature_over_mesh.m
% Create a quadrature for numerical integration over a whole mesh

%% Import the example sphere mesh
clear;
mesh = gmsh_import_mesh('../meshes/sphere.msh');
% Number of elements
n_elems = size(mesh.elements, 1);
% Plot the mesh with elem normals
plot_mesh(mesh);
plot_elem_normals(mesh);

%% Plot the element numbering
element_index = (1 : n_elems).';
plot_mesh(mesh, element_index);
%% Highlight the 1st element
e = zeros(n_elems, 1);
e(1) = 1;
plot_mesh(mesh, e);
%% Plot the distance of all elem centers from 1st element
[d, r] = mesh_distances(mesh);
plot_mesh(mesh, d(:, 1));
%% Plot quadrature orders based on distance
orders = bem_distance_to_order(r);
plot_mesh(mesh, orders(:, 1));

%% Create the quadrature points
[xp, ~, w] = mesh_quadrature_points(mesh, orders(:,1));
plot_mesh(mesh, orders(:,1));
hold on;
plot3(xp(:,1), xp(:,2), xp(:,3), 'r.');
set(gca, 'Clipping', 'off');
%% Calculate the sum of weights
S = sum(sum(w));