// Loudspeaker mesh for demonstration
// Created by Peter Rucz

// Inner radius parameter
// (inner radius of the inner membrane)
r_in = DefineNumber[ 0.02, Name "Parameters/r_in" ];
r_out = DefineNumber [0.11, Name "Parameters/r_out" ];
// Y position of membrane center
y_m = DefineNumber [0.15, Name "Parameters/y_m" ];
// Depth of membrane center
d_m = DefineNumber [0.04, Name "Parameters/d_m"];
// Length of the whole box
l_x = DefineNumber[ 0.25, Name "Parameters/l_x" ];
l_y = DefineNumber[ 0.38, Name "Parameters/l_y" ];
l_z = DefineNumber[ 0.22, Name "Parameters/l_z" ];

// Element size parameter
e = DefineNumber[ 0.015, Name "Parameters/e" ];

// Origin
Point(0) = {0, 0, 0, e};

// Top
Point(1001) = {-l_x/2, l_y - y_m, 0, e};
Point(1002) = { l_x/2, l_y - y_m, 0, e};
Point(1003) = { l_x/2, l_y - y_m, -l_z, e};
Point(1004) = {-l_x/2, l_y - y_m, -l_z, e};

// Bottom
Point(2001) = {-l_x/2, -y_m, 0, e};
Point(2002) = { l_x/2, -y_m, 0, e};
Point(2003) = { l_x/2, -y_m, -l_z, e};
Point(2004) = {-l_x/2, -y_m, -l_z, e};

// Outer midpoint
Point(3000) = {0, 0, 0, e};
Point(3001) = {r_out, 0, 0, e};
Point(3002) = {-r_out, 0, 0, e};

// Inner midpoint
Point(4000) = {0, 0, -d_m, e};
Point(4001) = {r_in, 0, -d_m, e};
Point(4002) = {-r_in, 0, -d_m, e};

Line(3501) = {3001, 4001};
Line(3502) = {3002, 4002};

// Dome center
Point(5000) = {0, 0, -d_m -2*r_in};
Point(5001) = {0, 0, -d_m + r_in/2};

// Membrane
Circle(300) = {3001, 3000, 3002};
Circle(301) = {3002, 3000, 3001};

Circle(400) = {4001, 4000, 4002};
Circle(401) = {4002, 4000, 4001};

Line Loop(30) = {300, 3502, -400, -3501};
Line Loop(40) = {301, 3501, -401, -3502};
Surface(31) = {30};
Surface(41) = {40};

Line Loop(60) = {400,401};
Plane Surface(61) = {60};

//Front
Line(201) = {2001, 2002};
Line(202) = {2002, 1002};
Line(203) = {1002, 1001};
Line(204) = {1001, 2001};
Line Loop(50) = {300, 301};
Line Loop(51) = {201, 202, 203, 204};
Plane Surface(52) = {51, 50};

// Top
Line(100) = {1002, 1003};
Line(101) = {1003, 1004};
Line(102) = {1004, 1001};
Line(103) = {1001, 1002};
Line Loop(10) = {100, 101, 102, 103};
Plane Surface(11) = {10};

//Bottom
Line(110) = {2002, 2003};
Line(111) = {2003, 2004};
Line(112) = {2004, 2001};
Line(113) = {2001, 2002};
Line Loop(12) = {110, 111, 112, 113};
Plane Surface(13) = {-12};

// Left plane
Line(120) = {2001, 1001};
Line(121) = {1001, 1004};
Line(122) = {1004, 2004};
Line(123) = {2004, 2001};
Line Loop(14) = {120, 121, 122, 123};
Plane Surface(15) = {14};

// Right plane
Line(130) = {2002, 1002};
Line(131) = {1002, 1003};
Line(132) = {1003, 2003};
Line(133) = {2003, 2002};
Line Loop(16) = {130, 131, 132, 133};
Plane Surface(17) = {-16};

// Back plane
Line(140) = {1003, 2003};
Line(141) = {2003, 2004};
Line(142) = {2004, 1004};
Line(143) = {1004, 1003};
Line Loop(18) = {140, 141, 142, 143};
Plane Surface(19) = {18};
