function ord = bem_distance_to_order(r)
%BEM_DISTANCE_TO_ORDER Convert relative distances to quadrature orders
%   ORD = BEM_DISTANCE_TO_ORDER(R) Calculates the quadrature polynomial
%   orders used in the non-singular numerical integration of the 
%   fundamental solutions. The order ORD is computed based on the relative
%   distances R. The resulting orders ORD will have the same size as the
%   input R.
%
%   The orders given in this function were calculated such that the
%   numerical integral using the Gaussian quadrature has a maximum relative
%   error of 0.1%.

% Relative distance base points
r_points = [0.0 1.1 1.5 2.8 15.8];
% Orders to use in between the above relative distance limits
o_points = [  8   6   4   2    0];

% Calculate the order by finding the appropriate distance limit 
ord = interp1(r_points, o_points, r, 'previous', 0);

end % of function bem_distance_to_order
