function [xx, ww] = elem_duffy_transform(xi, w)
%ELEM_DUFFY_TRANSFORM Duffy polar transform of a quadrature over an element 
%   [XX, WW] = ELEM_DUFFY_TRANSFORM(XI, W) Transforms the quadrature base 
%       points XI and weights W from the standard rectangular domain 
%       (-1,1) x (-1, 1) to the triangular domain with the corners (0, 0),
%       (1, 0), (0, 1). The origin of the polar transform is the (0, 0)
%       point in the triangular domain. The resulting quadrature is
%       applicable for both regular and singular integration.

% Corners of the standard triangle
corners = [
    0 0;
    0 0;
    1 0;
    0 1
];

N = elem_shape_functions(xi, 4);    % Shape functions of a linear quad
xx = N * corners;                   % Transform using the corners

% The Jacobian of the transform is (eta + 1)/8
% Apply this Jacobian in the weighting
ww = w .* (xi(:,2) + 1)/8;

end % of elem_duffy_transform

