function [N, dN] = elem_shape_functions(x, type)
%ELEM_SHAPE_FUNCTIONS Shape functions over standard elements
%   [N, dN] = ELEM_SHAPE_FUNCTIONS(X, TYPE) returns linear shape function 
%       samples over standard elements. The input matrix X is a M x D 
%       matrix, each row contains the coordinates [xi eta] of a point in 
%       the standard element. The output N contains the M samples of the 
%       shape function N(xi, eta), the output dN contains the derivatives
%       [N'_xi N'_eta] for each location.


switch type
    case 2
        % LINE element
        xi = x(:,1);
        N = [1-xi, 1+xi]/2;
        if nargout > 1
            dN = repmat([-1, +1]/2, size(xi,1),1);
        end
    case 3 
        % TRIA element
        xi = x(:,1);
        eta = x(:,2);
        N = [1-xi-eta, xi, eta];
        if nargout > 1
            dN(:,:,1) = repmat([-1, +1,  0], size(xi,1),1);
            dN(:,:,2) = repmat([-1,  0, +1], size(xi,1),1);
        end
    case 4 
        % QUAD element
        xi = x(:,1);
        eta = x(:,2);
        N = [(1-xi).*(1-eta), (1+xi).*(1-eta),...
            (1+xi).*(1+eta), (1-xi).*(1+eta)] / 4;
        if nargout > 1
            dN(:,:,1) = [-(1-eta), (1-eta), (1+eta), -(1+eta)] / 4;
            dN(:,:,2) = [-(1-xi), -(1+xi), (1+xi), (1-xi)] / 4;
        end
end
end % of function elem_shape_functions
