function [x, w] = gaussian_quadrature(n)
% GAUSSIAN_QUADRATURE Create Gauss-Legendre quadrature of given order
%   [X, W] = GAUSSIAN_QUADRATURE(N) Creates the base points X and the
%       weights W of a Gauss-Legendre quadrature with N points over the
%       standard domain [-1, 1].
%
%   According to the original program, concepts for finding the base points
%   and weight factors can be found on page 93 of "Methods of Numerical
%   Integration" by Philip Davis and Philip Rabinowitz.

%   Original version by:
%       Author:      Peter J. Acklam
%       Time-stamp:  2003-03-31 18:20:05 +0200
%       E-mail:      pjacklam@online.no
%       URL:         http://home.online.no/~pjacklam

u = 1:n-1;
u = u ./ sqrt(4*u.^2 - 1);

% Same as A = diag(u, -1) + diag(u, 1), but faster (no adding).
A = zeros( n, n );
A( 2 : n+1 : n*(n-1) ) = u;
A( n+1 : n+1 : n^2-1 ) = u;

% Find the base points X and weight factors W for the interval [-1,1].
[v, x] = eig(A);
[x, k] = sort(diag(x));
w = 2*v(1,k)'.^2;

end