function P = gmsh_import_params(fname)
%GMSH_IMPORT_PARAMS Import parameters defined in a gmsh geometry file
%   P = GMSH_IMPORT_PARAMS(FILENAME) Reads the parameters defined in a gmsh
%       geometry file (.geo). The output structure P will contain fields
%       named as the parameters defined in the geometry file.

fid = fopen(fname);
if (fid < 0)
    error('gmsh_import_params:file_error', ...
        'Could not open geometry file %s', fname);
end
text = textscan(fid, '%s','Delimiter', '\n');
fclose(fid);

text = text{1};
% Trim whitespaces from beginning and end of lines
text = cellfun(@strtrim, text, 'UniformOutput', false);
% Drop empty lines
num_chars = cellfun(@length, text);
text = text(num_chars > 0);

% Drop lines containing comments
text = text(~strncmp(text, '//', 2));

% Look for parameter definitions
defs = text(cellfun(@(x)~isempty(x), strfind(text, 'DefineNumber')));

defpattern = '^(?<name>\w+)\s*=\s*DefineNumber\s*\[\s*(?<value>\-?[0-9\.]+)';
tokens = regexp(defs, defpattern, 'names');


n = numel(tokens);
% Assemble structure
P = struct([]);
for i = 1 : n
    P(1).(tokens{i}.name) = str2double(tokens{i}.value);
end

end % of gmsh_import_params function

