function [centers, normals, areas] = mesh_element_props(mesh)
%MESH_ELEMENT_PROPS Compute element properties of a triangular mesh
%   [C, N, A] = MESH_ELEMENT_PROPS(MESH) Computes the element centers C, 
%       element normals N and element areas A of the triangular mesh MESH.
%       C and N are of type E x 3, where E is the number of elements in the
%       mesh. A is a column vector with E elements.

% Extract elements and nodes
tri = mesh.elements;
nod = mesh.nodes;

% Element centers are the mean of the coordinates
centers = 1/3*(nod(tri(:,1), :) + nod(tri(:,2), :) + nod(tri(:,3), :));
% Normals 
normals = cross(nod(tri(:,2),:) - nod(tri(:,1), :), ...
               nod(tri(:,3),:) - nod(tri(:,1), :), 2) / 2;

% Normalize the normal vector
areas = sqrt(dot(normals, normals, 2));
normals = bsxfun(@times, normals, 1./areas);

end % of function mesh_element_props
