function kmax = mesh_kmax(mesh, ratio)
%MESH_KMAX Compute the maximum allowed wave number on a triangular mesh
%   KMAX = MESH_KMAX(MESH, RATIO) Computes the maximum allowed wave number
%       for each element of the mesh. The maximum allowed wave number is
%       computed such that there are at least RATIO elements in one
%       wavelength. The linear size of each triangular element is estimated 
%       as the square root of twice its area. If the RATIO parameter is not
%       set, RATIO = 6 is set as the default value.

% Default ratio if not set
if nargin < 2
    ratio = 6;
end

% Find element areas
[~, ~, A] = mesh_element_props(mesh);
% Estimation of the linear size (edge length) of elements
elem_size = sqrt(2*A);
% Minimal wavelength allowed
lambda_min = ratio * elem_size;
% Maximal wavenumber allowed
kmax = 2*pi ./ lambda_min;

end % of function mesh_kmax
