function plot_elem_normals(mesh)
%PLOT_ELEM_NORMALS Plot element normals of a mesh
%   PLOT_ELEM_NORMALS(MESH) Plots the normal vectors of the elements of the
%       triangular mesh MESH. The length of the normal vectors drawn are 
%       the linear size estimates of the elements. Note that this function 
%       does not plot the elements themselves. Use plot_mesh to plot the 
%       elements.
%
%See also:
%   plot_mesh

% Extract centers, normals and areas.
[start, n, A] = mesh_element_props(mesh);

% plot lines and markers

stop = start + bsxfun(@times, n, sqrt(2*A));
line([start(:,1) stop(:,1)].',...
    [start(:,2) stop(:,2)].',...
    [start(:,3) stop(:,3)].',...
    'Color', 'black');
ih = ishold;
hold on;
plot3(start(:,1), start(:,2), start(:,3), '.k');
plot3(stop(:,1), stop(:,2), stop(:,3), '.r');

if ~ih
    hold off;
end

end % of function plot_elem_normals
